( cd usr/lib ; rm -rf libplc4.a )
( cd usr/lib ; ln -sf ../../lib/libplc4.a libplc4.a )
( cd usr/lib ; rm -rf libnspr4.so )
( cd usr/lib ; ln -sf ../../lib/libnspr4.so libnspr4.so )
( cd usr/lib ; rm -rf libnspr4.a )
( cd usr/lib ; ln -sf ../../lib/libnspr4.a libnspr4.a )
( cd usr/lib ; rm -rf libplds4.so )
( cd usr/lib ; ln -sf ../../lib/libplds4.so libplds4.so )
( cd usr/lib ; rm -rf libplc4.so )
( cd usr/lib ; ln -sf ../../lib/libplc4.so libplc4.so )
( cd usr/lib ; rm -rf libplds4.a )
( cd usr/lib ; ln -sf ../../lib/libplds4.a libplds4.a )
